@@ -14,6 +14,9 @@ import os
 import base64
 import numpy as np
 import requests
+from mobio.libs.Singleton import Singleton
+from mobio.libs.caching import LRUCacheDict
+from pathlib import Path
 
 
 class MobioCrypt1:
@@ -171,7 +174,11 @@ class MobioCrypt3:
             return None
 
 
+@Singleton
 class CryptUtil:
+    def __init__(self):
+        self.license_merchant = LRUCacheDict(expiration=900)
+
     @staticmethod
     def decrypt_mobio_crypt1(key_salt, text_encrypt):
         m = MobioCrypt1.g1(key_salt, 1, 0x1341589)
@@ -202,6 +209,21 @@ class CryptUtil:
                 time.sleep(0.1)
         return content_file
 
+    @staticmethod
+    def save_data_to_file(file_path, data):
+        while True:
+            try:
+                Path(os.path.dirname(os.path.abspath(file_path))).mkdir(
+                    parents=True, exist_ok=True
+                )
+                with open(file_path, "w") as fout:
+                    fout.write(data)
+                    fout.close()
+                break
+            except IOError as ex:
+                print("license_sdk::save_data_to_file():message: %s" % ex)
+                time.sleep(0.1)
+
     @staticmethod
     def get_license_info(license_key, merchant_id):
         license_info = None
@@ -274,11 +296,54 @@ class CryptUtil:
     def get_license_encrypt(merchant_id):
         license_encrypt = ""
         try:
-            if Mobio.vm_type:
-                file_path = CryptUtil.get_file_path_license(merchant_id)
-                license_encrypt = CryptUtil.get_content_from_file(file_path)
-            else:
-                license_encrypt = CryptUtil.get_file_license_from_admin(merchant_id)
+            license_encrypt = CryptUtil().license_merchant.getitem(merchant_id)
+            if not license_encrypt:
+                if Mobio.vm_type:
+                    if Mobio.AUTO_RENEW_FILE_LICENSE and Mobio.AUTO_RENEW_FILE_LICENSE == "yes":
+                        license_encrypt = CryptUtil.get_file_license_from_license(merchant_id)
+                        if license_encrypt:
+                            file_path = CryptUtil.get_file_path_license(merchant_id)
+                            CryptUtil.save_data_to_file(file_path, license_encrypt)
+                    if not license_encrypt:
+                        file_path = CryptUtil.get_file_path_license(merchant_id)
+                        license_encrypt = CryptUtil.get_content_from_file(file_path)
+                else:
+                    license_encrypt = CryptUtil.get_file_license_from_admin(merchant_id)
+                CryptUtil().license_merchant.set_item(merchant_id, license_encrypt)
         except Exception as ex:
             print("license_sdk::get_license_encrypt():message: {}".format(ex))
         return license_encrypt
+
+    @staticmethod
+    def get_file_license_from_license(merchant_id):
+        from .license_sdk import MobioLicenseSDK
+
+        license_encrypt = ""
+        try:
+            adm_url = str(UrlConfig.LICENSE_DOWNLOAD_FILE).format(
+                host=MobioLicenseSDK().admin_host,
+            )
+            request_header = {}
+            if MobioLicenseSDK().request_header:
+                request_header.update(MobioLicenseSDK().request_header)
+            params = {"merchant_id": merchant_id}
+            response = requests.get(
+                adm_url,
+                params=params,
+                headers=request_header,
+                timeout=MobioLicenseSDK.DEFAULT_REQUEST_TIMEOUT_SECONDS,
+            )
+            response.raise_for_status()
+            license_encrypt = response.text
+        except Exception as ex:
+            print("license_sdk::get_file_license_from_license():message: {}".format(ex))
+        return license_encrypt
+
+    @staticmethod
+    def encrypt_mobio_crypt2(data: str):
+        return MobioCrypt2.e1(data)
+
+    @staticmethod
+    def decrypt_mobio_crypt2(data: str):
+        return MobioCrypt2.d1(data, "utf-8")
+
