@@ -55,7 +55,7 @@ class LicenseDetailMessUsedModel(BaseCollectionMongoDB):
             return None
 
     def get_number_mess_used_from_mess_id(self, merchant_id, list_mess_id):
-        data_used = {}
+        data_used = dict()
         try:
             obj_match = {
                 self.merchant_id: merchant_id,
