@@ -61,7 +61,7 @@ class MobioLicenseSDK(object):
         self.module_use = module_use
         self.license_key = license_key
         if module_use:
-            self.request_header = {"X-Module-Request": module_use}
+            self.request_header = {"X-Module-Request": module_use,"X-Mobio_SDK": "LICENSE"}
         if module_use and module_encrypt:
             # if module_use == MobioCrypt2.d1(module_encrypt, enc="utf-8"):
             #     self.module_valid = True
@@ -179,3 +179,16 @@ class MobioLicenseSDK(object):
             "messages": messages,
             "success": allow_use_mess,
         }
+
+    @staticmethod
+    def encrypt2(data: str):
+        return CryptUtil.encrypt_mobio_crypt2(data)
+
+    @staticmethod
+    def decrypt2(data: str):
+        return CryptUtil.decrypt_mobio_crypt2(data)
+
+    @staticmethod
+    def decrypt1(key_salt: str, data: str):
+        return CryptUtil.decrypt_mobio_crypt1(key_salt, data)
+
