@@ -1,4 +1,4 @@
-from .crypt_utils import CryptUtil, MobioCrypt2
+from .crypt_utils import CryptUtil
 import datetime
 from .license_mess_used import LicenseMessUsedModel
 from .license_detail_mess_used import LicenseDetailMessUsedModel
@@ -160,7 +160,7 @@ class Utils:
         try:
             check_sum = data_mess.get(LicenseMessUsedModel.check_sum)
             data_text = LicenseMessUsedModel().data_mess_to_string(data_mess)
-            if MobioCrypt2.e1(data_text) == check_sum:
+            if CryptUtil.encrypt_mobio_crypt2(data_text) == check_sum:
                 data_invalid = True
         except Exception as ex:
             print("license_sdk::check_data_mess_used():message: {}".format(ex))
@@ -646,7 +646,7 @@ class Utils:
     @staticmethod
     def save_history_license_used_mess(data_mess):
         try:
-            check_sum = MobioCrypt2.e1(
+            check_sum = CryptUtil.encrypt_mobio_crypt2(
                 LicenseMessUsedModel().data_mess_to_string(data_mess)
             )
             data_mess[LicenseMessUsedModel.check_sum] = check_sum
